@@ -1,15 +1,16 @@
 package DateTime::Format::Epoch;
 
+use 5.00503; #qr
 use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use DateTime 0.22;
 use DateTime::LeapSecond;
 
-use Math::BigInt ('lib' => 'GMP,Pari,FastCalc');
+use Math::BigInt ('lib' => $^O eq 'MSWin32' ? 'Pari,FastCalc' : 'GMP,Pari,FastCalc');
 use Params::Validate qw/validate BOOLEAN OBJECT/;
 
 sub _floor {
